#include <port.h>
#include <stdio.h>
#include "args.h"
#include "imgformat.h"
#include "memory.h"

typedef struct PointType
  {
  float		x, y ;
  } Point ;


char	infile[1024], outfile[1024] ;
int	row, col, length = 5 ;
Point	*edge_list ;
int	edge_pt_count ;


args_t args[] = {
  ARG_DEF("i", TRUE, STRING, 1024, infile,
          "the name of the edge list file for input"),
  ARG_DEF("r", TRUE, INT, 1, &row,
          "the rows of the output image"),
  ARG_DEF("c", TRUE, INT, 1, &col,
          "the columns of the output image"),
  ARG_DEF("l", FALSE, INT, 1, &length,
          "the minimum length of edges (default 5)"),
  ARG_DEF("o", TRUE, STRING, 1024, outfile,
          "the name of the file to store the output edge image (PGM format)"),
  ARG_LAST
  } ;


int read_one_edge() ;


void main(int argc, char **argv)
  {
  FILE		*ifp ;
  PGMImage	*image ;
  int		i, j ;
  
  args_parse( argc, argv, args ) ;
  
  ifp = fopen(infile, "r") ;
  if (!ifp)
    {
    fprintf(stderr, "Fail to open input file %s ... exit!\n", infile) ;
    exit(-1) ;
    }
  
  edge_list = (Point *) calloc(row*col/2, sizeof(Point)) ;
  image = (PGMImage *) calloc(1, sizeof(PGMImage)) ;
  strcpy(image->MagicValue, PGM_RAW) ;
  image->ImageWidth = col ;
  image->ImageHeight = row ;
  image->MaxGray = 255 ;
  image->data = ucmatrix(row, col) ;
  for (i = 0 ; i < row ; i++)
    for (j = 0 ; j < col ; j++)
      image->data[i][j] = 0 ;
  
  while (read_one_edge(ifp))
    {
    if (edge_pt_count < length)
      continue ;
    for (i = 0 ; i < edge_pt_count ; i++)
      image->data[(int)edge_list[i].y][(int)edge_list[i].x] = 255 ;
    }
  fclose(ifp) ;
  
  write_pgm_file(outfile, image) ;
  free_pgm_data(image) ;
  }


int read_one_edge(FILE *ifp)
  {
  int		i ;
  float		tx, ty ;
  
  edge_pt_count = 0 ;
  for (i = 0 ; i < row * col / 2 ; i++)
    edge_list[i].x = edge_list[i].y = 0.0 ;
  
  while (fscanf(ifp, "%f %f\n", &tx, &ty) != EOF)
    {
    if (tx == -1 && ty == -1)
      return 1 ;
    edge_list[edge_pt_count].x = tx ;
    edge_list[edge_pt_count].y = ty ;
    ++edge_pt_count ;
    }
  return 0 ;
  }